bai2 package
============

Submodules
----------

bai2.bai2 module
----------------

.. automodule:: bai2.bai2
    :members:
    :undoc-members:
    :show-inheritance:

bai2.constants module
---------------------

.. automodule:: bai2.constants
    :members:
    :undoc-members:
    :show-inheritance:

bai2.exceptions module
----------------------

.. automodule:: bai2.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

bai2.helpers module
-------------------

.. automodule:: bai2.helpers
    :members:
    :undoc-members:
    :show-inheritance:

bai2.models module
------------------

.. automodule:: bai2.models
    :members:
    :undoc-members:
    :show-inheritance:

bai2.parsers module
-------------------

.. automodule:: bai2.parsers
    :members:
    :undoc-members:
    :show-inheritance:

bai2.utils module
-----------------

.. automodule:: bai2.utils
    :members:
    :undoc-members:
    :show-inheritance:

bai2.writers module
-------------------

.. automodule:: bai2.writers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bai2
    :members:
    :undoc-members:
    :show-inheritance:
